API Reference
=============


echo
----

.. automodule:: termlog.echo
   :members:
   :undoc-members:
   :show-inheritance:


colors
------

.. automodule:: termlog.colors
   :members:
   :undoc-members:
   :show-inheritance:


formatting
----------

.. automodule:: termlog.formatting
   :members:
   :undoc-members:
   :show-inheritance:


message
-------

.. automodule:: termlog.message
   :members:
   :undoc-members:
   :show-inheritance:
